@@ -8,15 +8,15 @@ class SqlParser:
     clauses = [
         "SELECT",
         "FROM",
-        "LEFT JOIN",
-        "LEFT OUTER JOIN",
-        "RIGHT JOIN",
-        "RIGHT OUTER JOIN",
-        "FULL JOIN",
-        "FULL OUTER JOIN",
-        "INNER JOIN",
+        "LEFT (?:OUTER )?JOIN",
+        "RIGHT (?:OUTER )?JOIN",
+        "FULL (?:OUTER )?JOIN",
+        "(?:INNER )?JOIN",
         "WHERE",
         "QUALIFY",
+        "GROUP BY",
+        "ORDER BY",
+        "HAVING",
     ]
 
     @classmethod
@@ -33,7 +33,7 @@ class SqlParser:
         string = re.sub(r"#.*", "", string)  # remove comments
         string = re.sub(r"\s+", " ", string)  # standardize whitespace
         string = re.sub(r"\/\*.*\*\/", "", string)  # remove comments
-        string = string.strip().lower()
+        string = string.strip().lower().lstrip("(").rstrip(")")
         return string
 
     def _clean_list(self, lst: List[str]) -> List[str]:
@@ -51,49 +51,64 @@ class SqlParser:
         keys = ["content", "alias"]
         return dict(zip(keys, self._clean_split(value, r"\s+as\s+")))
 
-    def _split_select_value(self, value: str) -> List[Dict[str, str]]:
-        """SELECT statement value splitting"""
-        select_statements = self._clean_split(value, ",")
-        return list(map(self._split_value_into_content_and_alias, select_statements))
-
     def _split_source_value(self, value: str) -> Dict[str, str]:
-        """Value splitting for sources (FROM / JOIN)"""
+        """Value splitting for sources (origin FROM / JOIN)"""
         split_on_whitespace = self._clean_split(value)
 
-        if len(split_on_whitespace) == 2:
+        if len(split_on_whitespace) > 1:
             split_on_whitespace.insert(1, "as")
 
         value = " ".join(split_on_whitespace)
         return self._split_value_into_content_and_alias(value)
 
-    def _split_join_on(self, value: str) -> Dict[str, List[str]]:
-        """JOIN statement value splitting"""
+    def _split_join_on_value(self, value: str) -> Dict[str, List[str]]:
+        """Value splitting join on specifications"""
         return {"on": self._clean_split(value, r"\s+and\s+")}
 
     def _split_join_value(self, value: str) -> Dict[str, Union[str, List[str]]]:
-        """Join on value splitting"""
+        """Value splitting for joins"""
         source, join_on = self._clean_split(value, r"\s+on\s+", maxsplit=1)
 
-        return {**self._split_source_value(source), **self._split_join_on(join_on)}
+        return {
+            **self._split_source_value(source),
+            **self._split_join_on_value(join_on),
+        }
 
     def _split_condition_value(self, value: str) -> List[str]:
-        """Condition statement value splitting (WHERE / QUALIFY)"""
+        """Value splitting for conditions (WHERE / QUALIFY / HAVING)"""
         return self._clean_split(value, r"\s+and\s+")
 
+    def _split_enumeration_value(
+        self, clause: str, value: str
+    ) -> Union[List[str], List[Dict[str, str]]]:
+        """Value splitting for enumerations (SELECT, GROUP BY, ORDER BY)"""
+        statements = self._clean_split(value, ",")
+        if clause == "select":
+            return list(map(self._split_value_into_content_and_alias, statements))
+        return statements
+
     def _split_value(self, clause: str, value: str) -> Any:
         """Function for splitting values based on right clause"""
         return (
-            self._split_select_value(value)
-            if clause == "select"
-            else self._split_source_value(value)
+            self._split_source_value(value)
             if clause == "from"
             else self._split_join_value(value)
             if "join" in clause
             else self._split_condition_value(value)
-            if clause in ("where", "qualify")
+            if clause in ("where", "qualify", "having")
+            else self._split_enumeration_value(clause, value)
+            if clause in ("select", "group by", "order by")
             else value
         )
 
+    def _standardize_clauses(self, clauses: List[str]) -> List[str]:
+        # remove outer keyword (LEFT/RIGHT/FULL OUTER JOIN)
+        clauses = [re.sub(" outer ", " ", clause) for clause in clauses]
+        # map join to inner join
+        clauses = ["inner join" if clause == "join" else clause for clause in clauses]
+
+        return clauses
+
     @substitute_brackets
     def _split_clauses_and_values(self, query: str) -> Tuple[List[str], List[str]]:
         """Starting point for parsing. Split into clauses and values."""
@@ -102,7 +117,7 @@ class SqlParser:
         clauses = self._clean_list(re.findall(reg, query, flags=re.I))
         values = self._clean_list(re.split(reg, query, flags=re.I))
 
-        return clauses, values
+        return self._standardize_clauses(clauses), values
 
     def parse(self, input_string: str) -> Union[list, dict]:
         """Callable for user."""
@@ -110,7 +125,7 @@ class SqlParser:
 
     def _parse(self, input_string: str) -> Union[list, dict]:
         """Test for unions -> leads to different parsing layout."""
-        union_split = self._clean_split(input_string, r"UNION\s+(?:ALL)?")
+        union_split = self._clean_split(input_string, r"UNION (?:ALL)?")
 
         if len(union_split) == 1:
             return self._parse_query(input_string)
@@ -132,9 +147,7 @@ class SqlParser:
             # Detect inner SQL
             if "join" in clause or clause == "from":
                 if "select" in split_value["content"]:
-                    without_brackets = (
-                        split_value["content"].strip().lstrip("(").rstrip(")")
-                    )
+                    without_brackets = self._clean_string(split_value["content"])
                     # Continue parsing inner SQL
                     split_value["content"] = self._parse(without_brackets)
 
